It fixes the wrong log info when fails to unregister vhost driver.

Signed-off-by: Changchun Ouyang <changchun.ouyang at intel.com>
---
 examples/vhost/main.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/examples/vhost/main.c b/examples/vhost/main.c
index 7863dcf..72c4773 100644
--- a/examples/vhost/main.c
+++ b/examples/vhost/main.c
@@ -3051,10 +3051,10 @@ main(int argc, char *argv[])
        if (mergeable == 0)
                rte_vhost_feature_disable(1ULL << VIRTIO_NET_F_MRG_RXBUF);

        /* Register CUSE device to handle IOCTLs. */
        ret = rte_vhost_driver_register((char *)&dev_basename);
        if (ret != 0)
-               rte_exit(EXIT_FAILURE,"CUSE device setup failure.\n");
+               rte_exit(EXIT_FAILURE,"vhost driver register failure.\n");

        rte_vhost_driver_callback_register(&virtio_net_device_ops);
@@ -3051,10 +3051,10 @@ main(int argc, char *argv[])
                rte_vhost_feature_disable(1ULL << VIRTIO_NET_F_MRG_RXBUF);

-       /* Register CUSE device to handle IOCTLs. */
+       /* Register vhost driver to handle IOCTLs. */
        ret = rte_vhost_driver_register((char *)&dev_basename);
        if (ret != 0)

-- 
1.8.4.2

Reply via email to